CompanionManager class

A class that handles the available companions and using them

When making a custom companion type, make sure to register it or else some features might not work

Inheritance

Constructors

CompanionManager()
const

Properties

activeTypes List<CompanionType>
Returns all the active companion types
no setteroverride
allTypes List<CompanionType>
Returns all the companion types
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(CompanionType companionType) → void
Removes companionType from the active companion types and from all companions types list
override
getType(String type) CompanionType
Returns the corresponding companion type from all companions with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(CompanionType companionType) → void
Adds companionType to the list of all companion types and active companions types
override
toString() String
A string representation of this object.
inherited
unregisterType(CompanionType companionType) → void
Removes companionType only from the active companions
override

Operators

operator ==(Object other) bool
The equality operator.
inherited