Deity class

A class that represents the deity entity

Constructors

Deity({required String name, Gender? gender, required DeityType deityType, required List<String> domains, Alignment? alignment, required String depiction, Race? worshipedBy, required String worshipers, required String shrinesRarity, required String positiveAttribute, required String negativeAttribute})
const
Deity.fromJson(String source)
factory
Deity.fromMap(Map<String, dynamic> map)
factory
Deity.fromShallowMap(Map<String, dynamic> map)
factory

Properties

alignment → Alignment?
The alignment of this deity, null for unaligned
final
deityType → DeityType
The type of the deity (god, angel, demon, etc.)
final
depiction → String
How this deity is depicted
final
domains → List<String>
A list of domains related to this deity
final
gender → Gender?
The gender of the deity, null for genderless
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the deity
final
negativeAttribute → String
A negative attribute of this deity, often how their nonbelievers believe they are
final
positiveAttribute → String
A positive attribute of this deity, often how their worshipers believe they are
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shrinesRarity → String
How rare are shrines for this deity
final
worshipedBy → Race?
The race who worship this deity, null if this deity is worshiped by many races
final
worshipers → String
A description of how many worshippers this deity has
final

Methods

copyWith({String? name, Gender? gender, DeityType? deityType, List<String>? domains, Alignment? alignment, String? depiction, Race? worshipedBy, String? worshipers, String? shrinesRarity, String? positiveAttribute, String? negativeAttribute}) → Deity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Deity other) → bool
The equality operator.
override