negativeAttribute property
A negative attribute of this deity, often how their nonbelievers believe they are
Implementation
final String negativeAttribute;
A negative attribute of this deity, often how their nonbelievers believe they are
final String negativeAttribute;