positiveAttribute property
A positive attribute of this deity, often how their worshipers believe they are
Implementation
final String positiveAttribute;
A positive attribute of this deity, often how their worshipers believe they are
final String positiveAttribute;