DeityManager class

A class that handles the available deities and using them

When making a custom deity type, make sure to register it or else some features might not work

Inheritance

Constructors

DeityManager()
const

Properties

activeTypes → List<DeityType>
Returns all active deities
no setteroverride
allTypes → List<DeityType>
Returns all the deity types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(DeityType deityType) → void
Removes deityType from the active deity types and from all deity types list
override
getType(String type) → DeityType
Returns the corresponding deity type from all deities with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(DeityType deityType) → void
Adds deityType to the list of all deity types and active deity types
override
toString() → String
A string representation of this object.
inherited
unregisterType(DeityType deityType) → void
Removes deityType only from the active races
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited