Emblem class

A class that represents an emblem in svg

Constructors

Emblem({required SvgWrapper shape, required SvgWrapper pattern, required List<EmblemIcon> icons, required HslColor primaryColor, required HslColor secondaryColor, required HslColor iconsColor, required EmblemType type})
const
Emblem.fromJson(String source)
factory
Emblem.fromMap(Map<String, dynamic> map)
factory
Emblem.fromShallowMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
icons → List<EmblemIcon>
A map between icons on the emblem and their positions
final
iconsColor → HslColor
The icons color of the svg, in css valid format like "#12a43g" or "red"
final
pattern → SvgWrapper
The pattern of the emblem
final
primaryColor → HslColor
The primary color of the svg, in css valid format like "#12a43g" or "red"
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor → HslColor
The secondary color of the svg, in css valid format like "#12a43g" or "red"
final
shape → SvgWrapper
The svg of the shape of the emblem
final
type → EmblemType
The type of the emblem
final

Methods

buildSvg() → String
Builds an svg from the emblem data
copyWith({SvgWrapper? shape, SvgWrapper? pattern, List<EmblemIcon>? icons, HslColor? primaryColor, HslColor? secondaryColor, HslColor? iconsColor, EmblemType? type}) → Emblem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Emblem other) → bool
The equality operator.
override