EmblemIcon class

A class that represents an icon in an emblem

Constructors

EmblemIcon({required SvgWrapper svgWrapper, required IconPosition position})
const
EmblemIcon.fromJson(String source)
factory
EmblemIcon.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → IconPosition
The position of the icon
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
svgWrapper → SvgWrapper
The svg wrapper that represents the icon
final

Methods

copyWith({SvgWrapper? svgWrapper, IconPosition? position}) → EmblemIcon
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant EmblemIcon other) → bool
The equality operator.
override