EmblemIconsManager class

A class that handles the available deities and using them

When making a custom emblemIcon type, make sure to register it or else some features might not work

Inheritance

Constructors

EmblemIconsManager()
const

Properties

activeTypes → List<SvgWrapper>
Returns all active deities
no setteroverride
allTypes → List<SvgWrapper>
Returns all the emblemIcon types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(SvgWrapper emblemIcon) → void
Removes emblemIcon from the active emblemIcon types and from all emblemIcon types list
override
getType(String name) → SvgWrapper
Returns the corresponding emblemIcon from all deities with type name
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(SvgWrapper emblemIcon) → void
Adds emblemIcon to the list of all emblemIcon types and active emblemIcon types
override
toString() → String
A string representation of this object.
inherited
unregisterType(SvgWrapper emblemIcon) → void
Removes emblemIcon only from the active races
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited