EmblemPatternsManager class

A class that handles the available deities and using them

When making a custom emblemPattern type, make sure to register it or else some features might not work

Inheritance

Constructors

EmblemPatternsManager()
const

Properties

activeTypes → List<SvgWrapper>
Returns all active deities
no setteroverride
allTypes → List<SvgWrapper>
Returns all the emblemPattern types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(SvgWrapper emblemPattern) → void
Removes emblemPattern from the active emblemPattern types and from all emblemPattern types list
override
getType(String name) → SvgWrapper
Returns the corresponding emblemPattern from all deities with type name
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(SvgWrapper emblemPattern) → void
Adds emblemPattern to the list of all emblemPattern types and active emblemPattern types
override
toString() → String
A string representation of this object.
inherited
unregisterType(SvgWrapper emblemPattern) → void
Removes emblemPattern only from the active races
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited