EmblemShapesManager class

A class that handles the available deities and using them

When making a custom emblemShape type, make sure to register it or else some features might not work

Inheritance

Constructors

EmblemShapesManager()
const

Properties

activeTypes → List<SvgWrapper>
Returns all active deities
no setteroverride
allTypes → List<SvgWrapper>
Returns all the emblemShape types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(SvgWrapper emblemShape) → void
Removes emblemShape from the active emblemShape types and from all emblemShape types list
override
getType(String name) → SvgWrapper
Returns the corresponding emblemShape from all deities with type name
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(SvgWrapper emblemShape) → void
Adds emblemShape to the list of all emblemShape types and active emblemShape types
override
toString() → String
A string representation of this object.
inherited
unregisterType(SvgWrapper emblemShape) → void
Removes emblemShape only from the active races
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited