EmblemType class abstract

A class that represents an emblem type

Implementers

Constructors

EmblemType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmblemType() → String
Returns the type of the emblem
getIconGenerator() → Generator<SvgWrapper>
Returns a generator for an icon for this generator
getIconsColorGenerator(HslColor primaryColor, HslColor secondaryColor) → Generator<HslColor>
Returns a generator for the icon color of the emblem
getIconsCountGenerator() → Generator<int>
Returns a generator for how many icons an emblem has
getLayoutGenerator(int iconsCount) → Generator<List<IconPosition>>
Returns a generator for the layout of the icons based on how many there are
getPatternGenerator() → Generator<SvgWrapper>
Returns a generator for a pattern of an emblem
getPrimaryColorGenerator() → Generator<HslColor>
Returns a generator for the primary color of the emblem
getSecondaryColorGenerator(HslColor primaryColor) → Generator<HslColor>
Returns a generator for the secondary color of the emblem
getShapeGenerator() → Generator<SvgWrapper>
Returns a generator for a shape of an emblem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited