EmblemTypeManager class

A class that handles the available deities and using them

When making a custom emblem type, make sure to register it or else some features might not work

Inheritance

Constructors

EmblemTypeManager()
const

Properties

activeTypes → List<EmblemType>
Returns all active deities
no setteroverride
allTypes → List<EmblemType>
Returns all the emblem types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(EmblemType emblemType) → void
Removes emblemType from the active emblem types and from all emblem types list
override
getType(String type) → EmblemType
Returns the corresponding emblem type from all deities with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(EmblemType emblemType) → void
Adds emblemType to the list of all emblem types and active emblem types
override
toString() → String
A string representation of this object.
inherited
unregisterType(EmblemType emblemType) → void
Removes emblemType only from the active races
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited