Guild class

A class that represents a guild

Constructors

Guild({required String name, required Npc leader, required GuildType guildType, required String reputation, required String history, required Emblem emblem, required String motto, required List<String> specialties, required List<String> quests, required List<Npc> notableMembers})
const
Guild.fromJson(String source)
factory
Guild.fromMap(Map<String, dynamic> map)
factory
Guild.fromShallowMap(Map<String, dynamic> map)
factory

Properties

emblem → Emblem
The emblem of the guild
final
guildType → GuildType
The type of this guild
final
hashCode → int
The hash code for this object.
no setteroverride
history → String
A short history of this guild
final
leader → Npc
The leader of this guild
final
motto → String
The motto of this guild
final
name → String
The name of this guild
final
notableMembers → List<Npc>
A list of some notable members of this guild
final
quests → List<String>
A list of quests this guild is working on
final
reputation → String
The reputation of this guild
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialties → List<String>
A list of specialties of this guild
final

Methods

copyWith({String? name, Npc? leader, GuildType? guildType, String? reputation, String? history, Emblem? emblem, String? motto, List<String>? specialties, List<String>? quests, List<Npc>? notableMembers}) → Guild
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Guild other) → bool
The equality operator.
override