GuildManager class

A class that handles the available guilds and using them

When making a custom guild type, make sure to register it or else some features might not work

Inheritance

Constructors

GuildManager()
const

Properties

activeTypes → List<GuildType>
Returns all active guilds
no setteroverride
allTypes → List<GuildType>
Returns all the guild types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(GuildType guildType) → void
Removes guildType from the active guild types and from all guild types list
override
getType(String type) → GuildType
Returns the corresponding guild type from all guilds with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(GuildType guildType) → void
Adds guildType to the list of all guild types and active guild types
override
toString() → String
A string representation of this object.
inherited
unregisterType(GuildType guildType) → void
Removes guildType only from the active guild types
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited