GuildType class abstract

A class that represents a guild type

Implementers

Constructors

GuildType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmblemType() → EmblemType
Returns the emblem type for this guild type
getGuildType() → String
Returns the type of the guild
getHistoryGenerator(String guildName) → Generator<String>
Returns a generator for the history of the guild
getLeaderOccupation() → String
Returns the occupation of the guild leader
getMemberOccupationGenerator() → Generator<String>
Returns a generator for an occupation of a guild member
getMottoGenerator() → Generator<String>
Returns a generator for a guild motto
getNameGenerator() → Generator<String>
Returns a generator for a guild name
getQuestGenerator() → Generator<String>
Returns a generator for a quest of the guild
getReputationGenerator() → Generator<String>
Returns a generator for the reputation of a guild
getSpecialtyGenerator() → Generator<String>
Returns a generator for a specialty of the guild
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited