MerchantsGuild class

A class that represents a merchants guild

Implemented types

Constructors

MerchantsGuild()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmblemType() → EmblemType
Returns the emblem type for this guild type
override
getGuildType() → String
Returns the type of the guild
override
getHistoryGenerator(String guildName) → Generator<String>
Returns a generator for the history of the guild
override
getLeaderOccupation() → String
Returns the occupation of the guild leader
override
getMemberOccupationGenerator() → Generator<String>
Returns a generator for an occupation of a guild member
override
getMottoGenerator() → Generator<String>
Returns a generator for a guild motto
override
getNameGenerator() → Generator<String>
Returns a generator for a guild name
override
getQuestGenerator() → Generator<String>
Returns a generator for a quest of the guild
override
getReputationGenerator() → Generator<String>
Returns a generator for the reputation of a guild
override
getSpecialtyGenerator() → Generator<String>
Returns a generator for a specialty of the guild
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited