Celebration class

Implemented types

Constructors

Celebration()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCelebratorsGenerator() Generator<String>
Returns a generator for who celebrates this holiday
override
getDateGenerator() Generator<String>
Returns a generator for a holiday's date
override
getDurationGenerator() Generator<String>
Returns a generator for a holiday's duration
override
getFixed(Holiday holiday) Holiday
Returns the fixed version of object
override
getHolidayType() String
Returns the type of the holiday
override
getNameGenerator() Generator<String>
Returns a generator for a holiday name
override
getOriginGenerator() Generator<String>
Returns a generator for a holiday's origin
override
getTraditionGenerator() Generator<String>
Returns a generator for a tradition of a holiday
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited