HolidayManager class

A class that handles the available holidays and using them

When making a custom holiday type, make sure to register it or else some features might not work

Inheritance

Constructors

HolidayManager()
const

Properties

activeTypes List<HolidayType>
Returns all active holidays
no setteroverride
allTypes List<HolidayType>
Returns all the holiday types
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(HolidayType holidayType) → void
Removes holidayType from the active holiday types and from all holiday types list
override
getType(String type) HolidayType
Returns the corresponding holiday type from all holidays with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(HolidayType holidayType) → void
Adds holidayType to the list of all holiday types and active holiday types
override
toString() String
A string representation of this object.
inherited
unregisterType(HolidayType holidayType) → void
Removes holidayType only from the active holiday types
override

Operators

operator ==(Object other) bool
The equality operator.
inherited