HolidayType class abstract

A class that represents a holiday type

Implementers

Constructors

HolidayType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCelebratorsGenerator() → Generator<String>
Returns a generator for who celebrates this holiday
getDateGenerator() → Generator<String>
Returns a generator for a holiday's date
getDurationGenerator() → Generator<String>
Returns a generator for a holiday's duration
getHolidayType() → String
Returns the type of the holiday
getNameGenerator() → Generator<String>
Returns a generator for a holiday name
getOriginGenerator() → Generator<String>
Returns a generator for a holiday's origin
getTraditionGenerator() → Generator<String>
Returns a generator for a tradition of a holiday
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited