GovernmentType class abstract

A class that represents a government type

Implementers

Constructors

GovernmentType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGovernmentType() → String
Returns the type of the government
getLeaderOccupation(Gender gender) → String
Returns the occupation of the leader of the kingdom by their gender
getNumberOfLeadersGenerator() → Generator<int>
Returns a generator for how many leaders there are
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited