KingdomGenerator class

Implemented types

Constructors

KingdomGenerator(KingdomType _kingdomType, Race _race, GovernmentType _governmentType)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() Kingdom
Generates an item of type T
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seed(int seed) → void
Seeds the generator with a number
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited