KingdomType class abstract

A class that represents a generic kingdom type

Implementers

Constructors

KingdomType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCapitalTypeGenerator() → Generator<SettlementType>
Returns a generator for the settlement type for the capital of a kingdom
getEmblemType() → EmblemType
Returns the emblem type used by this kingdom type
getGuildTypeGenerator() → Generator<GuildType>
Returns a generator for the type of the guilds in the kingdom
getHistoryGenerator(String kingdomName) → Generator<String>
Returns a generator for the history of the kingdom
getHolidayTypeGenerator() → Generator<HolidayType>
Returns a generator for a type of holiday that exist in the kingdom
getImportantSettlementsTypesGenerator() → Generator<SettlementType>
Returns a generator for the type of other important settlements in the kingdom
getKingdomType() → String
Returns the type of the settings kingdom
getKnownForGenerator() → Generator<String>
Returns a generator for something a kingdom is known for
getNameGenerator(Race race) → Generator<String>
Returns a generator for a kingdom's name
getPopulationGenerator() → Generator<int>
Returns a generator for the population of a kingdom
getTroubleGenerator() → Generator<String>
Returns a generator for a trouble a kingdom has
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited