getCapitalTypeGenerator abstract method
Returns a generator for the settlement type for the capital of a kingdom
Implementation
Generator<SettlementType> getCapitalTypeGenerator();
Returns a generator for the settlement type for the capital of a kingdom
Generator<SettlementType> getCapitalTypeGenerator();