getHolidayTypeGenerator abstract method
Returns a generator for a type of holiday that exist in the kingdom
Implementation
Generator<HolidayType> getHolidayTypeGenerator();
Returns a generator for a type of holiday that exist in the kingdom
Generator<HolidayType> getHolidayTypeGenerator();