KingdomTypeManager class

A class that handles the available kingdoms and using them

When making a custom kingdom type, make sure to register it or else some features might not work

Inheritance

Constructors

KingdomTypeManager()
const

Properties

activeTypes List<KingdomType>
Returns all active kingdoms
no setteroverride
allTypes List<KingdomType>
Returns all the kingdom types
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(KingdomType kingdomType) → void
Removes kingdomType from the active kingdom types and from all kingdom types list
override
getType(String type) KingdomType
Returns the corresponding kingdom type from all kingdoms with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(KingdomType kingdomType) → void
Adds kingdomType to the list of all kingdom types and active kingdom types
override
toString() String
A string representation of this object.
inherited
unregisterType(KingdomType kingdomType) → void
Removes kingdomType only from the active races
override

Operators

operator ==(Object other) bool
The equality operator.
inherited