LandscapeManager class

A class that handles the available landscapes and using them

When making a custom landscape type, make sure to register it or else some features might not work

Inheritance

Constructors

LandscapeManager()
const

Properties

activeTypes List<LandscapeType>
Returns all active landscapes
no setteroverride
allTypes List<LandscapeType>
Returns all the landscape types
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(LandscapeType landscapeType) → void
Removes landscapeType from the active landscape types and from all landscape types list
override
getType(String type) LandscapeType
Returns the corresponding landscape type from all landscapes with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(LandscapeType landscapeType) → void
Adds landscapeType to the list of all landscape types and active landscape types
override
toString() String
A string representation of this object.
inherited
unregisterType(LandscapeType landscapeType) → void
Removes landscapeType only from the active races
override

Operators

operator ==(Object other) bool
The equality operator.
inherited