Alignment class

A class that represent an alignment of an npc

Constructors

Alignment({required EthicalAlignment ethical, required MoralAlignment moral})
const
Alignment.fromJson(String source)
factory
Alignment.fromMap(Map<String, dynamic> map)
factory

Properties

ethical → EthicalAlignment
final
hashCode → int
The hash code for this object.
no setteroverride
moral → MoralAlignment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EthicalAlignment? ethical, MoralAlignment? moral}) → Alignment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Alignment other) → bool
The equality operator.
override