Personality class

A class that represents a personality of an npc

Constructors

Personality({required Alignment alignment, required List<String> traits, required List<String> quirks, required List<String> descriptors})
const
Personality.fromJson(String source)
factory
Personality.fromMap(Map<String, dynamic> map)
factory

Properties

alignment → Alignment
The alignment of the npc
final
descriptors → List<String>
A list of adjectives that described the npc
final
hashCode → int
The hash code for this object.
no setteroverride
quirks → List<String>
A list of personality quirks the npc has
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traits → List<String>
A list of personality traits the npc has
final

Methods

copyWith({Alignment? alignment, List<String>? traits, List<String>? quirks, List<String>? descriptors}) → Personality
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Personality other) → bool
The equality operator.
override