PhysicalDescription class

A class that represents the physical description of an npc

Constructors

PhysicalDescription({required Hair hairStyle, required String eyes, required String skin, required int height, required String build, required String face, Hair? beard, required List<String> specialFeatures})
const
PhysicalDescription.fromJson(String source)
factory
PhysicalDescription.fromMap(Map<String, dynamic> map)
factory

Properties

beard → Hair?
The beard of this npc (if has)
final
build → String
The physical build of this npc (muscular, lean, etc.)
final
eyes → String
The eye color of this npc
final
face → String
The face of this npc
final
hairStyle → Hair
The hair style of this npc. For some races it might be head shape or something else
final
hashCode → int
The hash code for this object.
no setteroverride
height → int
The height of this npc in centimeters
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skin → String
final
specialFeatures → List<String>
List of special features this npc has
final

Methods

copyWith({Hair? hairStyle, String? eyes, String? skin, int? height, String? build, String? face, Hair? beard, List<String>? specialFeatures}) → PhysicalDescription
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant PhysicalDescription other) → bool
The equality operator.
override