City class

A class that represents the city settlement type

Implemented types

Constructors

City()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDescriptionGenerator(String settlementName, Race? dominantRace) → Generator<String>
Returns a generator for the settlement description
override
getDominantOccupationGenerator() → Generator<String>
Returns a generator for dominant occupations for this settlement type
override
getImportantOccupationGenerator() → Generator<String>
Returns a generator for important characters' occupations
override
getImportantPeopleCount() → int
Returns how many important people are there in this settlement type
override
getLocationsTypeGenerator() → Generator<LocationType>
Returns a generator for random location types for this settlement type
override
getNameGenerator(Race? dominantRace) → Generator<String>
Returns the name of the town
override
getPopulationGenerator() → Generator<int>
Returns a generator for the settlement type population
override
getSettlementsLocations() → List<LocationType?>
Returns the settlements locations, when null means a random type
override
getSettlementType() → String
Returns the settlement type
override
getTroubleGenerator() → Generator<String>
Returns a generator for a trouble this settlement type might have
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited