Goods class

A class that represents goods that can be found in various locations

Constructors

Goods({required String name, String? description, String? price})
const
Goods.fromJson(String source)
factory
Goods.fromMap(Map<String, dynamic> map)
factory

Properties

description → String?
The description of the goods
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the goods
final
price → String?
The price of the goods, null if there is no price
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? description, String? price}) → Goods
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Goods other) → bool
The equality operator.
override