SettlementManager class

A class that handles the available settlements and using them

When making a custom settlement type, make sure to register it or else some features might not work

Inheritance

Constructors

SettlementManager()
const

Properties

activeTypes → List<SettlementType>
Returns all active settlements
no setteroverride
allTypes → List<SettlementType>
Returns all the settlement types
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(SettlementType settlementType) → void
Removes settlementType from the active location types and from all location types list
override
getType(String type) → SettlementType
Returns the corresponding settlement type from all settlements from type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(SettlementType settlementType) → void
Adds settlementType to the list of all location types and active location types
override
toString() → String
A string representation of this object.
inherited
unregisterType(SettlementType settlementType) → void
Removes settlementType only from the active races
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited