SettlementType class abstract

A class that represents an abstract settlement type

Implementers

Constructors

SettlementType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDescriptionGenerator(String settlementName, Race? dominantRace) → Generator<String>
Returns a generator for the settlement description
getDominantOccupationGenerator() → Generator<String>
Returns a generator for dominant occupations for this settlement type
getImportantOccupationGenerator() → Generator<String>
Returns a generator for important characters' occupations
getImportantPeopleCount() → int
Returns how many important people are there in this settlement type
getLocationsTypeGenerator() → Generator<LocationType>
Returns a generator for random location types for this settlement type
getNameGenerator(Race? dominantRace) → Generator<String>
Returns the name of the town
getPopulationGenerator() → Generator<int>
Returns a generator for the settlement type population
getSettlementsLocations() → List<LocationType?>
Returns the settlements locations, when null means a random type
getSettlementType() → String
Returns the settlement type
getTroubleGenerator() → Generator<String>
Returns a generator for a trouble this settlement type might have
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited