getSettlementsLocations abstract method

List<LocationType?> getSettlementsLocations()

Returns the settlements locations, when null means a random type

For example, the following list: [Tavern(), GeneralShop(), null, null] means that there is always a tavern and a general shop in the location, and two other randomly generated locations

Implementation

List<LocationType?> getSettlementsLocations();