IslandsWorldMapSettings class

A setting that generates maps with many islands

Implemented types

Constructors

IslandsWorldMapSettings()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSettingName() → String
Returns the name of the setting
override
getTerrainFromHeight(double height) → Terrain
Returns the correct terrain type based on the height. Height is between -1 and 1
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited