WorldMap class

A class that represents a world map

Constructors

WorldMap({required WorldMapSettings settings, required Image image})
WorldMap.fromJson(String source)
factory
WorldMap.fromMap(Map<String, dynamic> map)
factory
WorldMap.fromShallowMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
image → Image
The image of the world map
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → WorldMapSettings
The settings of the world map
final

Methods

copyWith({WorldMapSettings? settings, Image? image}) → WorldMap
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant WorldMap other) → bool
The equality operator.
override