WorldMapSettingsManager class

A class that handles the available world map settings and using them

When making a custom world map settings, make sure to register it or else some features might not work

Inheritance

Constructors

WorldMapSettingsManager()
const

Properties

activeTypes → List<WorldMapSettings>
Returns all active world map settings
no setteroverride
allTypes → List<WorldMapSettings>
Returns all the world map settings
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(WorldMapSettings worldMapSettings) → void
Removes worldMapSettings from the active world map settings and from all world map settings list
override
getType(String name) → WorldMapSettings
Returns the corresponding world map settings from all world map settings from name name
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(WorldMapSettings worldMapSettings) → void
Adds worldMapSettings to the list of all world map settings and active world map settings
override
toString() → String
A string representation of this object.
inherited
unregisterType(WorldMapSettings worldMapSettings) → void
Removes worldMapSettings only from the active settings
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited