World class

A class that represents a world

Constructors

World({required String name, required WorldSettings worldSettings, required List<Kingdom> kingdoms, required List<Landscape> landscapes, required Map<Race, String> opinions, required List<Npc> importantPeople, required List<Guild> guilds, required List<Deity> deities, required List<Deity> lesserDeities, required List<Deity> higherDeities, required WorldLore worldLore, required List<Holiday> holidays, required WorldMap worldMap})
const
World.fromJson(String source)
factory
World.fromMap(Map<String, dynamic> map)
factory
World.fromShallowMap(Map<String, dynamic> map)
factory

Properties

deities → List<Deity>
The deities of the world
final
guilds → List<Guild>
Guilds that work in a worldwide scale in this world
final
hashCode → int
The hash code for this object.
no setteroverride
higherDeities → List<Deity>
Higher deities of the world
final
holidays → List<Holiday>
The holidays that exist in the world
final
importantPeople → List<Npc>
Notable characters in the world
final
kingdoms → List<Kingdom>
List of kingdoms in this world
final
landscapes → List<Landscape>
Notable landscapes in the world
final
lesserDeities → List<Deity>
Lesser deities of the world
final
name → String
The name of the world
final
opinions → Map<Race, String>
Opinions of the other races on each race
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worldLore → WorldLore
The lore of the world
final
worldMap → WorldMap
The map of the world
final
worldSettings → WorldSettings
The settings of the generated world
final

Methods

copyWith({String? name, WorldSettings? worldSettings, List<Kingdom>? kingdoms, List<Landscape>? landscapes, Map<Race, String>? opinions, List<Npc>? importantPeople, List<Guild>? guilds, List<Deity>? deities, List<Deity>? lesserDeities, List<Deity>? higherDeities, WorldLore? worldLore, List<Holiday>? holidays, WorldMap? worldMap}) → World
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant World other) → bool
The equality operator.
override