WorldLoreManager class

A class that handles the available worldLores and using them

When making a custom worldLore type, make sure to register it or else some features might not work

Inheritance

Constructors

WorldLoreManager()
const

Properties

activeTypes List<WorldLoreType>
Returns all active worldLores
no setteroverride
allTypes List<WorldLoreType>
Returns all the worldLore types
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(WorldLoreType worldLoreType) → void
Removes worldLoreType from the active world lore types and from all world lore types list
override
getType(String type) WorldLoreType
Returns the corresponding worldLore type from all worldLores from type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(WorldLoreType worldLoreType) → void
Adds worldLoreType to the list of all world lore types and active world lore types
override
toString() String
A string representation of this object.
inherited
unregisterType(WorldLoreType worldLoreType) → void
Removes worldLoreType only from the active races
override

Operators

operator ==(Object other) bool
The equality operator.
inherited