WorldSettings class abstract

A class that represents an abstract world settings

Implementers

Constructors

WorldSettings()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeitiesGenerator() → Generator<List<Deity>>
Returns a generator for a list of the main deities in the world
getGuildTypeGenerator() → Generator<GuildType>
Returns a generator for a guild type in the world
getHigherDeitiesGenerator() → Generator<List<Deity>>
Returns a generator for a list of higher deities in this world settings
getHolidayTypeGenerator() → Generator<HolidayType>
Returns a generator for a type of holiday that the world has
getImportantOccupationGenerator() → Generator<String>
Returns a generator for the occupation of the important people in the world settings
getImportantPeopleCount() → int
Returns how many important people to generate for this world settings
getKingdomsCountGenerator() → Generator<int>
Returns a generator for how many kingdoms to generate
getKingdomType() → KingdomType
Returns a kingdom type used for generation
getLandscapeTypeGenerator() → Generator<LandscapeType>
Returns a generator for random landscape types
getLandscapeTypes() → List<LandscapeType?>
Returns a list of landscape types, where null is a random landscape type
getLesserDeitiesGenerator() → Generator<List<Deity>>
Returns a generator for a list of lesser deities in this world settings
getNameGenerator() → Generator<String>
Returns a generator for the name of the world
getSettingName() → String
Returns the name of this world settings
getWorldLore() → WorldLoreType
Returns the world lore type object for generating a lore for this world settings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited