getImportantPeopleCount abstract method
Returns how many important people to generate for this world settings
Implementation
int getImportantPeopleCount();
Returns how many important people to generate for this world settings
int getImportantPeopleCount();