WorldSettingsManager class

A class that handles the available world settings and using them

When making a custom world settings, make sure to register it or else some features might not work

Inheritance

Constructors

WorldSettingsManager()
const

Properties

activeTypes → List<WorldSettings>
Returns all active world settings
no setteroverride
allTypes → List<WorldSettings>
Returns all the world settings
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(WorldSettings worldSettings) → void
Removes worldSettings from the active world settings and from all world settings list
override
getType(String name) → WorldSettings
Returns the corresponding world settings from all world settings from name name
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(WorldSettings worldSettings) → void
Adds worldSettings to the list of all world settings and active world settings
override
toString() → String
A string representation of this object.
inherited
unregisterType(WorldSettings worldSettings) → void
Removes worldSettings only from the active settings
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited