string_manipulations library

Functions

article(String string) → String
Returns the string with "a" or "an" in the beginning
titled(String string) → String
Returns the string with the first character in upper case
titledEach(String string) → String
Returns the string when each word starts with a capital letter
toGerund(String verb) → String
Returns the verb with the "ing" suffix