DeityManager class
A class that handles the available deities and using them
When making a custom deity type, make sure to register it or else some features might not work
Constructors
- DeityManager()
-
const
Properties
-
activeTypes
→ List<
DeityType> -
Returns all active deities
no setteroverride
-
allTypes
→ List<
DeityType> -
Returns all the deity types
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteType(
DeityType deityType) → void -
Removes
deityTypefrom the active deity types and from all deity types listoverride -
getType(
String type) → DeityType -
Returns the corresponding deity type from all deities with type
typeoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerType(
DeityType deityType) → void -
Adds
deityTypeto the list of all deity types and active deity typesoverride -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterType(
DeityType deityType) → void -
Removes
deityTypeonly from the active racesoverride
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited