DeityType class abstract

A class that represents a generic deity type

Implementers

Constructors

DeityType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeityTitle(Gender? gender) String
Returns the title of the deity based on its gender (god and goddess, demon and demoness, etc.)
getDeityType() String
Returns the name of the type of the deity
getDepictionGenerator(Race? worshipedBy) Generator<String>
Returns a generator for how this being is depicted
getDomainGenerator(Alignment? alignment) Generator<String>
Returns a generator for one domain this being is related to
getGenderGenerator() Generator<Gender?>
Returns a generator for the gender of the deity
getNameGenerator(Gender? gender, Race? worshipedBy) Generator<String>
Returns a generator for the name of the deity
getNegativeAttributeGenerator() Generator<String>
Returns a generator for a negative attribute this being has
getPositiveAttributeGenerator() Generator<String>
Returns a generator for a positive attribute this being has
getShrinesRarityGenerator() Generator<String>
Returns a generator for how rare are shrines for this being
getWorshipedByGenerator() Generator<Race?>
Returns a generator for the race that worship this being
getWorshipersGenerator() Generator<String>
Returns a generator for a description of how many worshippers this deity has
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited