HolidayManager class
A class that handles the available holidays and using them
When making a custom holiday type, make sure to register it or else some features might not work
- Inheritance
-
- Object
- Manager<
HolidayType> - HolidayManager
Constructors
- HolidayManager()
-
const
Properties
-
activeTypes
→ List<
HolidayType> -
Returns all active holidays
no setteroverride
-
allTypes
→ List<
HolidayType> -
Returns all the holiday types
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteType(
HolidayType holidayType) → void -
Removes
holidayTypefrom the active holiday types and from all holiday types listoverride -
getType(
String type) → HolidayType -
Returns the corresponding holiday type from all holidays with type
typeoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerType(
HolidayType holidayType) → void -
Adds
holidayTypeto the list of all holiday types and active holiday typesoverride -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterType(
HolidayType holidayType) → void -
Removes
holidayTypeonly from the active holiday typesoverride
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited