Kingdom class
Constructors
-
Kingdom({required String name, required KingdomType kingdomType, required List<
Npc> rulers, required Race race, required int population, required Settlement capital, required List<Settlement> importantSettlements, required GovernmentType governmentType, required Emblem emblem, required String knownFor, required String history, required List<Guild> guilds, required String trouble, required List<Holiday> holidays}) - Kingdom.fromJson(String source)
-
factory
-
Kingdom.fromMap(Map<
String, dynamic> map) -
factory
-
Kingdom.fromShallowMap(Map<
String, dynamic> map) -
factory
Properties
- capital → Settlement
-
The capital of the kingdom
final
- emblem → Emblem
-
The emblem of the kingdom
final
- governmentType → GovernmentType
-
The government type of the kingdom
final
-
guilds
→ List<
Guild> -
List of guilds that operate in this kingdom
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- history → String
-
The history of the kingdom
final
-
holidays
→ List<
Holiday> -
The holidays that exist in the kingdom
final
-
importantSettlements
→ List<
Settlement> -
Some important settlements in the kingdom
final
- kingdomType → KingdomType
-
The type of the kingdom generation settings
final
- knownFor → String
-
Something this kingdom is known for
final
- name → String
-
The name of the kingdom
final
- population → int
-
The population of the kingdom
final
- race → Race
-
The race of the kingdom
final
-
rulers
→ List<
Npc> -
The rulers of the kingdom
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trouble → String
-
A trouble this kingdom have
final
Methods
-
copyWith(
{String? name, KingdomType? kingdomType, List< Npc> ? rulers, Race? race, int? population, Settlement? capital, List<Settlement> ? importantSettlements, GovernmentType? governmentType, Emblem? emblem, String? knownFor, String? history, List<Guild> ? guilds, String? trouble, List<Holiday> ? holidays}) → Kingdom -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant Kingdom other) → bool -
The equality operator.
override