KingdomTypeManager class
A class that handles the available kingdoms and using them
When making a custom kingdom type, make sure to register it or else some features might not work
- Inheritance
-
- Object
- Manager<
KingdomType> - KingdomTypeManager
Constructors
- KingdomTypeManager()
-
const
Properties
-
activeTypes
→ List<
KingdomType> -
Returns all active kingdoms
no setteroverride
-
allTypes
→ List<
KingdomType> -
Returns all the kingdom types
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteType(
KingdomType kingdomType) → void -
Removes
kingdomTypefrom the active kingdom types and from all kingdom types listoverride -
getType(
String type) → KingdomType -
Returns the corresponding kingdom type from all kingdoms with type
typeoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerType(
KingdomType kingdomType) → void -
Adds
kingdomTypeto the list of all kingdom types and active kingdom typesoverride -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterType(
KingdomType kingdomType) → void -
Removes
kingdomTypeonly from the active racesoverride
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited