LocationManager class

A class that handles the available locations and using them

When making a custom location type, make sure to register it or else some features might not work

Inheritance

Constructors

LocationManager()
const

Properties

activeTypes List<LocationType>
Returns all active locations
no setteroverride
allTypes List<LocationType>
Returns all the location types
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteType(LocationType locationType) → void
Removes locationType from the active location types and from all location types list
override
getType(String type) LocationType
Returns the corresponding location type from all locations with type type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(LocationType locationType) → void
Adds locationType to the list of all location types and active location types
override
toString() String
A string representation of this object.
inherited
unregisterType(LocationType locationType) → void
Removes locationType only from the active races
override

Operators

operator ==(Object other) bool
The equality operator.
inherited