LocationManager class
A class that handles the available locations and using them
When making a custom location type, make sure to register it or else some features might not work
- Inheritance
-
- Object
- Manager<
LocationType> - LocationManager
Constructors
- LocationManager()
-
const
Properties
-
activeTypes
→ List<
LocationType> -
Returns all active locations
no setteroverride
-
allTypes
→ List<
LocationType> -
Returns all the location types
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteType(
LocationType locationType) → void -
Removes
locationTypefrom the active location types and from all location types listoverride -
getType(
String type) → LocationType -
Returns the corresponding location type from all locations with type
typeoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerType(
LocationType locationType) → void -
Adds
locationTypeto the list of all location types and active location typesoverride -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterType(
LocationType locationType) → void -
Removes
locationTypeonly from the active racesoverride
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited