LocationType class abstract
A class that represent an abstract location type
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBuildingDescriptionGenerator(
String locationType, String locationName, Npc owner) → Generator< String> - Returns the building description generator
-
getGoodsGenerator(
) → Generator< List< Goods> ?> - Returns the goods generator for this location type
-
getLocationType(
) → String - Returns the location type
-
getNameGenerator(
Npc owner) → Generator< String> - Returns the name generator for this location type
-
getOutsideDescription(
) → Generator< String> - Returns the outside description generator for this location type
-
getOwnerOccupation(
) → String - Returns the occupation of the owner
-
getZoneGenerator(
) → Generator< String> - Returns the zone generator for this location type
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited